<template>
    <div>
        <div class="module-cart-billing block-billing">
            FACTURACIÓN <span>{{ formatCurrency(subtotal) }}</span>
        </div>
        <BillingMethod ref="billingMethodRef" />
        <hr class="hr-divisor" />
        <div class="module-cart-billing">
            ENVÍO<span>{{ formatCurrencyShipping(shippingCost) }}</span>
        </div>
        <ShippingFull ref="shippingMethodRef" />
        <hr class="hr-divisor" />
        <div class="module-cart-billing">
            MÉTODO DE PAGO<span>{{ formatCurrencyPayment(paymentDiscount) }}</span>
        </div>
        <PaymentMethod />
        <hr class="hr-divisor" />
        <TotalsCart />
        <button class="just-button total-button" :disabled="isSubmitting" @click="finalizePurchase">
            Finalizar Compra
        </button>
    </div>
</template>

<script setup>
import { computed, ref, watch } from "vue";
import BillingMethod from "./BillingMethod.vue";
import ShippingFull from "./ShippingFull.vue";
import { cartStore } from "../../../js/stores/cart";
import TotalsCart from "../TotalsCart.vue";
import PaymentMethod from "../Summary/PaymentMethod.vue";

const store = cartStore();

const billingMethodRef = ref(null);
const shippingMethodRef = ref(null);

const isFormBillingValid = ref(false);
const isFormShippingValid = ref(false);
const isSubmitting = ref(false);

const subtotal = computed(() => store.subtotal);
const shippingCost = computed(() => store.getShippingCost());
const paymentDiscount = computed(() => store.getPaymentDiscount());

watch(shippingCost, () => store.getShippingCost());
watch(paymentDiscount, () => store.getPaymentDiscount());

const formatCurrency = (value) => {
    return new Intl.NumberFormat("es-AR", {
        style: "currency",
        currency: "ARS",
        minimumFractionDigits: 2,
        maximumFractionDigits: 2,
    }).format(value);
};

const formatCurrencyShipping = (value) => {
    if (value === 0) {
        return "Gratis";
    }
    return new Intl.NumberFormat("es-AR", {
        style: "currency",
        currency: "ARS",
        minimumFractionDigits: 2,
        maximumFractionDigits: 2,
    }).format(value);
};

const formatCurrencyPayment = (value) => {
    if (value === 0) {
        return "";
    }
    return (
        "-" +
        new Intl.NumberFormat("es-AR", {
            style: "currency",
            currency: "ARS",
            minimumFractionDigits: 2,
            maximumFractionDigits: 2,
        }).format(value)
    );
};

async function finalizePurchase() {
    if (isSubmitting.value) return; // Evita el doble envío

    isFormBillingValid.value = billingMethodRef.value.validateBillingForm();

    isFormShippingValid.value = shippingMethodRef.value.validateShippingForm();

    if (isFormBillingValid.value && isFormShippingValid.value) {
        isSubmitting.value = true; // Marca el estado como en proceso

        const order = {
            items: store.items,
            shipping: store.selectedShippingMethod,
            payment: store.selectedPaymentMethod,

            billingName: store.billingName,
            billingSurname: store.billingSurname,
            billingDni: store.billingDni,
            billingEmail: store.billingEmail,
            billingPhone: store.billingPhone,
            wantInvoice: store.wantInvoice,
            invoicingCuit: store.invoicingCuit,
            invoicingCompanyName: store.invoicingCompanyName,
            invoicingAddress: store.invoicingAddress,
            invoicingCity: store.invoicingCity,
            address: store.address,
            number: store.number,
            dpto: store.dpto,
            floor: store.floor,
            receiveDni: store.receiveDni,
            receiveEmail: store.receiveEmail,
            receiveName: store.receiveName,
            receiveSurname: store.receiveSurname,
            receivePhone: store.receivePhone,
            selectedBranch: store.selectedBranch,
            selectedCity: store.selectedCity,
            selectedPostalCode: store.selectedPostalCode,
            selectedProvince: store.selectedProvince,
        };

        try {
            await sendOrderData(order);
        } catch (error) {
            console.error("Error al enviar los datos:", error);
            alert("Hubo un error al procesar la compra.");
        } finally {
            isSubmitting.value = false; // Libera el estado
        }
    } else {
        //alert('Por favor, completa todos los campos correctamente.');
    }
}

async function sendOrderData(order) {
    const response = await fetch("/create-order", {
        method: "POST",
        headers: {
            "Content-Type": "application/json",
        },
        body: JSON.stringify({ order }),
    });

    const data = await response.json();

    if (data && data.redirectUrl) {
        store.clearCart();
        window.location.href = data.redirectUrl;
    } else {
        alert("Hubo un error al procesar la compra.");
    }
}
</script>

<style lang="scss">
@use "../../../scss/variables" as vars;

.block-billing {
    margin-top: 10px;
}

.module-cart-billing {
    text-transform: uppercase;
    font-family: "Plus Jakarta Sans", sans-serif;
    font-weight: 800;
    padding-bottom: 20px;

    span {
        float: right;
        font-size: 16px;
    }
}

.total-button[disabled] {
    border: 1px solid #999 !important;
    background-color: #565656 !important;
}
</style>
